ViewportState

Struct ViewportState 

pub struct ViewportState {
    clip_state: ClipState,
    strip_generator: StripGenerator,
    strip_generator_stack: Vec<StripGenerator>,
    level: Level,
}
Viewport state storing information about clip state and active strip generators in currently active root viewports.

Fields

clip_state: ClipStatestrip_generator: StripGeneratorstrip_generator_stack: Vec<StripGenerator>level: Level

Implementations

Source

impl ViewportState

pub fn new(width: u16, height: u16, level: Level) -> Self

Create a new viewport state.

pub fn width(&self) -> u16

Width of the active viewport.

pub fn height(&self) -> u16

Height of the active viewport.

pub fn clip(&self) -> Option<PathDataRef<'_>>

Return the current clip path.

pub fn has_root_viewports(&self) -> bool

Whether any root viewports are currently pushed.

pub fn with_generator_and_clip<R>( &mut self, f: impl FnOnce(&mut StripGenerator, Option<PathDataRef<'_>>) -> R, ) -> R

Use the active strip generator together with the current clip.

pub fn push_clip( &mut self, path: &BezPath, fill_rule: Fill, transform: Affine, aliasing_threshold: Option<u8>, )

Push a new clip path.

pub fn pop_clip(&mut self)

Pop the last clip path.

pub fn push_root_viewport(&mut self, filter_data: &FilterData)

Push a new root viewport.

pub fn pop_root_viewport(&mut self)

Pop the last root viewport.

pub fn reset(&mut self, width: u16, height: u16)

Reset strip generation and clipping for a new viewport.